==> jc-1.4.0.tar.gz: javax/swing/JFormattedTextField__24FormatterFactoryWrapper.h <==
// class javax.swing.JFormattedTextField$FormatterFactoryWrapper

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e3da04f50ec7ee11 javax_swing_JFormattedTextField__24AbstractFormatterFactory
// @dep_class 416a27feaaef0045 javax_swing_JFormattedTextField__24FormatterFactoryWrapper

// header file dependencies
// @dep_header javax_swing_JFormattedTextField__24AbstractFormatterFactory

#include "javax/swing/JFormattedTextField__24AbstractFormatterFactory.h"

#ifndef _JC_javax_swing_JFormattedTextField__24FormatterFactoryWrapper_H_
#define _JC_javax_swing_JFormattedTextField__24FormatterFactoryWrapper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JFormattedTextField$object;
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object;

// Typedefs
typedef struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_refs	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_refs;
typedef struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_nonrefs	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_nonrefs;
typedef struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$refs	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$refs;
typedef struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$nonrefs	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$nonrefs;
typedef struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object;

typedef const struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vmethods	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vmethods;
typedef const struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtable	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtable;
typedef const struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtype	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtype;

// Constructors
extern void _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$_init$e2b2bbb2fb22dc9a(_jc_env *, struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object *, struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object *);

// Virtual methods
extern struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object *_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$getFormatter$05eb5d4d7bcf381f(_jc_env *, struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object *, struct _jc_javax_swing_JFormattedTextField$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method_info$getFormatter$05eb5d4d7bcf381f;

// Virtual methods structure
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vmethods {
	struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object	*(*getFormatter$05eb5d4d7bcf381f)(_jc_env *, struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object *, struct _jc_javax_swing_JFormattedTextField$object *);
};

// Vtable
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vmethods	javax_swing_JFormattedTextField__24AbstractFormatterFactory;
	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vmethods	javax_swing_JFormattedTextField__24FormatterFactoryWrapper;
};

// Vtype
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtype {
	_jc_type			type;
	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_refs {
	struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object	*formatter;
};

// Reference instance fields (object)
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$refs {
    _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_refs	javax_swing_JFormattedTextField__24FormatterFactoryWrapper;
    _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_refs	javax_swing_JFormattedTextField__24AbstractFormatterFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_nonrefs	javax_swing_JFormattedTextField__24AbstractFormatterFactory;
    _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_nonrefs	javax_swing_JFormattedTextField__24FormatterFactoryWrapper;
};

// Object instance structure
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object {
	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtype	*vtype;
	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtype _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JFormattedTextField__24FormatterFactoryWrapper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$class_object;

#endif	/* _JC_javax_swing_JFormattedTextField__24FormatterFactoryWrapper_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JFormattedTextField__24FormatterFactoryWrapper.h <==
// class javax.swing.JFormattedTextField$FormatterFactoryWrapper

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e3da04f50ec7ee11 javax_swing_JFormattedTextField__24AbstractFormatterFactory
// @dep_class 416a27feaaef0045 javax_swing_JFormattedTextField__24FormatterFactoryWrapper

// header file dependencies
// @dep_header javax_swing_JFormattedTextField__24AbstractFormatterFactory

#include "javax/swing/JFormattedTextField__24AbstractFormatterFactory.h"

#ifndef _JC_javax_swing_JFormattedTextField__24FormatterFactoryWrapper_H_
#define _JC_javax_swing_JFormattedTextField__24FormatterFactoryWrapper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JFormattedTextField$object;
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object;

// Typedefs
typedef struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_refs	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_refs;
typedef struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_nonrefs	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_nonrefs;
typedef struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$refs	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$refs;
typedef struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$nonrefs	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$nonrefs;
typedef struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object;

typedef const struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vmethods	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vmethods;
typedef const struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtable	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtable;
typedef const struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtype	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtype;

// Constructors
extern void _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$_init$e2b2bbb2fb22dc9a(_jc_env *, struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object *, struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object *_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$getFormatter$05eb5d4d7bcf381f(_jc_env *, struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object *, struct _jc_javax_swing_JFormattedTextField$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method_info$getFormatter$05eb5d4d7bcf381f;

// Virtual methods structure
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vmethods {
	struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object	*(*getFormatter$05eb5d4d7bcf381f)(_jc_env *, struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object *, struct _jc_javax_swing_JFormattedTextField$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vmethods	javax_swing_JFormattedTextField__24AbstractFormatterFactory;
	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vmethods	javax_swing_JFormattedTextField__24FormatterFactoryWrapper;
};

// Vtype
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtype {
	_jc_type			type;
	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_refs {
	struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object	*formatter;
};

// Reference instance fields (object)
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$refs {
    _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_refs	javax_swing_JFormattedTextField__24FormatterFactoryWrapper;
    _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_refs	javax_swing_JFormattedTextField__24AbstractFormatterFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_nonrefs	javax_swing_JFormattedTextField__24AbstractFormatterFactory;
    _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$sub_nonrefs	javax_swing_JFormattedTextField__24FormatterFactoryWrapper;
};

// Object instance structure
struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object {
	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtype	*vtype;
	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtype _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JFormattedTextField__24FormatterFactoryWrapper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$class_object;

#endif	/* _JC_javax_swing_JFormattedTextField__24FormatterFactoryWrapper_H_ */
